"""Default headers for session."""

SESSION_HEADERS = {
    'Content-type': 'application/json',
    'Accept': 'application/json',
    'User-Agent': 'ibs-jsonrpc',
    'Accept-Charset': 'utf-8',
    'Cache-Control': 'no-cache',
}
