"""Get users with expiration date and first login API method."""
from ibsng.handler.handler import Handler


class getUsersExpDateFirstLogin(Handler):
    """Get users with expiration date and first login method class."""

    pass
