"""Create session for failed user by ip API method."""
from ibsng.handler.handler import Handler


class createSessionForFailedUserByIP(Handler):
    """Create session for failed user by ip method class."""

    pass
