"""Get extra charge profile names API method."""
from ibsng.handler.handler import Handler


class getExtraChargeProfileNames(Handler):
    """Get extra charge profile names method class."""

    pass
