"""Get list of permission templates API method."""
from ibsng.handler.handler import Handler


class getListOfPermTemplates(Handler):
    """Get list of permission templates method class."""

    pass
